@@ -16,7 +16,7 @@ LOAD_BALANCER_ROWS = (
     'admin_state_up',
     'created_at',
     'description',
-    'flavor',
+    'flavor_id',
     'id',
     'listeners',
     'name',
@@ -70,7 +70,10 @@ LISTENER_ROWS = (
     'timeout_member_connect',
     'timeout_member_data',
     'timeout_tcp_inspect',
-    'updated_at')
+    'updated_at',
+    'client_ca_tls_container_ref',
+    'client_authentication',
+    'client_crl_container_ref')
 
 LISTENER_COLUMNS = (
     'id',
@@ -97,7 +100,11 @@ POOL_ROWS = (
     'protocol',
     'provisioning_status',
     'session_persistence',
-    'updated_at')
+    'updated_at',
+    'tls_container_ref',
+    'ca_tls_container_ref',
+    'crl_container_ref',
+    'tls_enabled')
 
 POOL_COLUMNS = (
     'id',
@@ -147,11 +154,13 @@ L7POLICY_ROWS = (
     'updated_at',
     'redirect_pool_id',
     'redirect_url',
+    'redirect_prefix',
     'action',
     'position',
     'id',
     'operating_status',
-    'name')
+    'name',
+    'redirect_http_code')
 
 L7POLICY_COLUMNS = (
     'id',
@@ -204,7 +213,9 @@ MONITOR_ROWS = (
     'url_path',
     'type',
     'id',
-    'operating_status'
+    'operating_status',
+    'http_version',
+    'domain_name'
 )
 
 MONITOR_COLUMNS = (
@@ -252,6 +263,7 @@ AMPHORA_ROWS = (
     'created_at',
     'updated_at',
     'image_id',
+    'compute_flavor',
 )
 
 AMPHORA_COLUMNS = (
@@ -262,3 +274,41 @@ AMPHORA_COLUMNS = (
     'lb_network_ip',
     'ha_ip',
 )
+
+PROVIDER_COLUMNS = (
+    'name',
+    'description',
+)
+
+PROVIDER_CAPABILICY_COLUMNS = (
+    'name',
+    'description',
+)
+
+FLAVOR_ROWS = (
+    'id',
+    'name',
+    'flavor_profile_id',
+    'enabled',
+    'description',
+)
+
+FLAVOR_COLUMNS = (
+    'id',
+    'name',
+    'flavor_profile_id',
+    'enabled',
+)
+
+FLAVORPROFILE_ROWS = (
+    'id',
+    'name',
+    'provider_name',
+    'flavor_data'
+)
+
+FLAVORPROFILE_COLUMNS = (
+    'id',
+    'name',
+    'provider_name',
+)
